BaseApplicationVerifier class abstract

Implemented types
Implementers

Constructors

BaseApplicationVerifier()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProducerProjectNumber(FirebaseAuth auth) Future<String>
getRecaptchaEnterpriseSiteKey(FirebaseAuth auth, {bool useNativeVerifier = true}) Future<String>
getRecaptchaSiteKey(FirebaseAuth auth) Future<String>
isRecaptchaEnterpriseEnabledForAction(FirebaseAuth auth, String action) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(FirebaseAuth auth, {bool forceRecaptcha = false, required String action, required String nonce}) Future<ApplicationVerificationResult>
inherited
verifyIosClient(FirebaseAuth auth, {required String appToken, required bool isSandbox}) Future<Duration>

Operators

operator ==(Object other) bool
The equality operator.
inherited