FirebaseDart class

Constructors

FirebaseDart(PureDartFirebaseImplementation _installation)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

launchUrl(Uri url, {bool popup = false}) → void
Opens the given url in a browser context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

baseUrl Uri
latefinal
instance FirebaseDart
Returns the current FirebaseDart instance representing the setup that was configured via FirebaseDart.setup.
no setter

Static Methods

setup({String? storagePath, Platform? platform, bool isolated = false, dynamic launchUrl(Uri url, {bool popup})?, AuthHandler? authHandler, ApplicationVerifier? applicationVerifier, SmsRetriever? smsRetriever, Client? httpClient}) → void
Initializes the pure dart firebase implementation.
updateDatabaseConfiguration({Duration? keepQueriesSyncedDuration}) → void
Updates global database configurations and optimization settings.